@@ -1,8 +1,8 @@
 /*
-  $Id: Common.h 15854 2013-04-02 09:35:24Z sloot $
+  $Id: Common.h 16820 2014-01-06 10:12:30Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/include/timbl/Common.h $
 
-  Copyright (c) 1998 - 2013
+  Copyright (c) 1998 - 2014
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -40,8 +40,8 @@ namespace Common {
   
   std::string Version();
   std::string VersionName();
-  std::string VersionInfo( bool = false );
-  void ShowVersionInfo( std::ostream& );
+  std::string BuildInfo();
+  std::string VersionInfo( bool ); // obsolete
 
   inline int look_ahead( std::istream &is ){
     int nc;
