@@ -1,8 +1,8 @@
 /*
-  $Id: Common.cxx 15854 2013-04-02 09:35:24Z sloot $
+  $Id: Common.cxx 16820 2014-01-06 10:12:30Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/Common.cxx $
 
-  Copyright (c) 1998 - 2013
+  Copyright (c) 1998 - 2014
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -35,21 +35,17 @@ using namespace std;
 
 namespace Common {
 
-  void ShowVersionInfo( std::ostream& os, bool full ){
-    os << VERSION;
-    if ( full )
-      os << ", compiled on " << __DATE__ << ", " << __TIME__;
-  }
-  
   string VersionInfo( bool full ){
-    string result;
-    ostringstream oss;
-    ShowVersionInfo( oss, full );
-    result = oss.str();
-    return result; 
+    // obsolete
+    if ( full )
+      return BuildInfo();
+    else
+      return Version();
   }
-
   string Version() { return VERSION; }
   string VersionName() { return PACKAGE_STRING; }
+  string BuildInfo() { 
+    return Version() + ", compiled on " + __DATE__ + ", " +  __TIME__;
+  }
 
 }
